new = {
"ABA ": {"name":"Abaza"}, 
"ABK ": {"name":"Abkhazian"}, 
"ACH ": {"name":"Acholi"}, 
"ACR ": {"name":"Achi"}, 
"ADY ": {"name":"Adyghe"}, 
"AFK ": {"name":"Afrikaans"}, 
"AFR ": {"name":"Afar"}, 
"AGW ": {"name":"Agaw"}, 
"AIO ": {"name":"Aiton"}, 
"AKA ": {"name":"Akan"}, 
"AKB ": {"name":"Batak"}, 
"ALS ": {"name":"Alsatian"}, 
"ALT ": {"name":"Altai"}, 
"AMH ": {"name":"Amharic"}, 
"ANG ": {"name":"Anglo"}, 
"ARA ": {"name":"Arabic"}, 
"ARG ": {"name":"Aragonese"}, 
"ARI ": {"name":"Aari"}, 
"ARK ": {"name":"Rakhine"}, 
"ASM ": {"name":"Assamese"}, 
"AST ": {"name":"Asturian"}, 
"ATH ": {"name":"Athapaskan"}, 
"AVN ": {"name":"Avatime"}, 
"AVR ": {"name":"Avar"}, 
"AWA ": {"name":"Awadhi"}, 
"AYM ": {"name":"Aymara"}, 
"AZB ": {"name":"Torki"}, 
"AZE ": {"name":"Azerbaijani"}, 
"BAD ": {"name":"Badaga"}, 
"BAG ": {"name":"Baghelkhandi"}, 
"BAL ": {"name":"Balkar"}, 
"BAN ": {"name":"Balinese"}, 
"BAR ": {"name":"Bavarian"}, 
"BAU ": {"name":"Baulé"}, 
"BBC ": {"name":"Batak"}, 
"BBR ": {"name":"Berber"}, 
"BCH ": {"name":"Bench"}, 
"BCR ": {"name":"Bible"}, 
"BDY ": {"name":"Bandjalang"}, 
"BEL ": {"name":"Belarussian"}, 
"BEM ": {"name":"Bemba"}, 
"BEN ": {"name":"Bengali"}, 
"BGC ": {"name":"Haryanvi"}, 
"BGQ ": {"name":"Bagri"}, 
"BGR ": {"name":"Bulgarian"}, 
"BHI ": {"name":"Bhili"}, 
"BHO ": {"name":"Bhojpuri"}, 
"BIK ": {"name":"Bikol"}, 
"BIL ": {"name":"Bilen"}, 
"BIS ": {"name":"Bislama"}, 
"BJJ ": {"name":"Kanauji"}, 
"BKF ": {"name":"Blackfoot"}, 
"BLI ": {"name":"Baluchi"}, 
"BLK ": {"name":"Pa’o"}, 
"BLN ": {"name":"Balante"}, 
"BLT ": {"name":"Balti"}, 
"BMB ": {"name":"Bambara"}, 
"BML ": {"name":"Bamileke"}, 
"BOS ": {"name":"Bosnian"}, 
"BPY ": {"name":"Bishnupriya"}, 
"BRE ": {"name":"Breton"}, 
"BRH ": {"name":"Brahui"}, 
"BRI ": {"name":"Braj"}, 
"BRM ": {"name":"Burmese"}, 
"BRX ": {"name":"Bodo"}, 
"BSH ": {"name":"Bashkir"}, 
"BSK ": {"name":"Burushaski"}, 
"BTD ": {"name":"Batak"}, 
"BTI ": {"name":"Beti"}, 
"BTK ": {"name":"Batak"}, 
"BTM ": {"name":"Batak"}, 
"BTS ": {"name":"Batak"}, 
"BTX ": {"name":"Batak"}, 
"BTZ ": {"name":"Batak"}, 
"BUG ": {"name":"Bugis"}, 
"BYV ": {"name":"Medumba"}, 
"CAK ": {"name":"Kaqchikel"}, 
"CAT ": {"name":"Catalan"}, 
"CBK ": {"name":"Zamboanga"}, 
"CEB ": {"name":"Cebuano"}, 
"CGG ": {"name":"Chiga"}, 
"CHA ": {"name":"Chamorro"}, 
"CHE ": {"name":"Chechen"}, 
"CHG ": {"name":"Chaha"}, 
"CHH ": {"name":"Chattisgarhi"}, 
"CHI ": {"name":"Chichewa"}, 
"CHK ": {"name":"Chukchi"}, 
"CHO ": {"name":"Choctaw"}, 
"CHP ": {"name":"Chipewyan"}, 
"CHR ": {"name":"Cherokee"}, 
"CHU ": {"name":"Chuvash"}, 
"CHY ": {"name":"Cheyenne"}, 
"CJA ": {"name":"Western"}, 
"CJM ": {"name":"Eastern"}, 
"CMR ": {"name":"Comorian"}, 
"COP ": {"name":"Coptic"}, 
"COR ": {"name":"Cornish"}, 
"COS ": {"name":"Corsican"}, 
"CPP ": {"name":"Creoles"}, 
"CRE ": {"name":"Cree"}, 
"CRR ": {"name":"Carrier"}, 
"CRT ": {"name":"Crimean"}, 
"CSB ": {"name":"Kashubian"}, 
"CSL ": {"name":"Church"}, 
"CSY ": {"name":"Czech"}, 
"CTG ": {"name":"Chittagonian"}, 
"CTT ": {"name":"Wayanad"}, 
"CUK ": {"name":"San"}, 
"DAG ": {"name":"Dagbani"}, 
"DAN ": {"name":"Danish"}, 
"DAR ": {"name":"Dargwa"}, 
"DAX ": {"name":"Dayi"}, 
"DCR ": {"name":"Woods"}, 
"DEU ": {"name":"German"}, 
"DGO ": {"name":"Dogri"}, 
"DGR ": {"name":"Dogri"}, 
"DHG ": {"name":"Dhangu"}, 
"DHV ": {"name":"Divehi"}, 
"DIQ ": {"name":"Dimli"}, 
"DIV ": {"name":"Divehi"}, 
"DJR ": {"name":"Zarma"}, 
"DNG ": {"name":"Dangme"}, 
"DNJ ": {"name":"Dan"}, 
"DNK ": {"name":"Dinka"}, 
"DRI ": {"name":"Dari"}, 
"DUJ ": {"name":"Dhuwal"}, 
"DUN ": {"name":"Dungan"}, 
"DZN ": {"name":"Dzongkha"}, 
"EBI ": {"name":"Ebira"}, 
"ECR ": {"name":"Eastern"}, 
"EDO ": {"name":"Edo"}, 
"EFI ": {"name":"Efik"}, 
"ELL ": {"name":"Greek"}, 
"EMK ": {"name":"Eastern"}, 
"ENG ": {"name":"English"}, 
"ERZ ": {"name":"Erzya"}, 
"ESP ": {"name":"Spanish"}, 
"ESU ": {"name":"Central"}, 
"ETI ": {"name":"Estonian"}, 
"EUQ ": {"name":"Basque"}, 
"EVK ": {"name":"Evenki"}, 
"EVN ": {"name":"Even"}, 
"EWE ": {"name":"Ewe"}, 
"FAN ": {"name":"French"}, 
"FAR ": {"name":"Persian"}, 
"FAT ": {"name":"Fanti"}, 
"FIN ": {"name":"Finnish"}, 
"FJI ": {"name":"Fijian"}, 
"FLE ": {"name":"Dutch"}, 
"FMP ": {"name":"Fe’fe’"}, 
"FNE ": {"name":"Forest"}, 
"FON ": {"name":"Fon"}, 
"FOS ": {"name":"Faroese"}, 
"FRA ": {"name":"French"}, 
"FRC ": {"name":"Cajun"}, 
"FRI ": {"name":"Frisian"}, 
"FRL ": {"name":"Friulian"}, 
"FRP ": {"name":"Arpitan"}, 
"FTA ": {"name":"Futa"}, 
"FUL ": {"name":"Fulah"}, 
"FUV ": {"name":"Nigerian"}, 
"GAD ": {"name":"Ga"}, 
"GAE ": {"name":"Scottish"}, 
"GAG ": {"name":"Gagauz"}, 
"GAL ": {"name":"Galician"}, 
"GAR ": {"name":"Garshuni"}, 
"GAW ": {"name":"Garhwali"}, 
"GEZ ": {"name":"Geez"}, 
"GIH ": {"name":"Githabul"}, 
"GIL ": {"name":"Gilyak"}, 
"GKP ": {"name":"Kpelle"}, 
"GLK ": {"name":"Gilaki"}, 
"GMZ ": {"name":"Gumuz"}, 
"GNN ": {"name":"Gumatj"}, 
"GOG ": {"name":"Gogo"}, 
"GON ": {"name":"Gondi"}, 
"GRN ": {"name":"Greenlandic"}, 
"GRO ": {"name":"Garo"}, 
"GUA ": {"name":"Guarani"}, 
"GUC ": {"name":"Wayuu"}, 
"GUF ": {"name":"Gupapuyngu"}, 
"GUJ ": {"name":"Gujarati"}, 
"GUZ ": {"name":"Gusii"}, 
"HAI ": {"name":"Haitian"}, 
"HAI0": {"name":"Haida"}, 
"HAL ": {"name":"Halam"}, 
"HAR ": {"name":"Harauti"}, 
"HAU ": {"name":"Hausa"}, 
"HAW ": {"name":"Hawaiian"}, 
"HAY ": {"name":"Haya"}, 
"HAZ ": {"name":"Hazaragi"}, 
"HBN ": {"name":"Hammer"}, 
"HEI ": {"name":"Heiltsuk"}, 
"HER ": {"name":"Herero"}, 
"HIL ": {"name":"Hiligaynon"}, 
"HIN ": {"name":"Hindi"}, 
"HMA ": {"name":"High"}, 
"HMD ": {"name":"A"}, 
"HMN ": {"name":"Hmong"}, 
"HMO ": {"name":"Hiri"}, 
"HMZ ": {"name":"Hmong"}, 
"HND ": {"name":"Hindko"}, 
"HO  ": {"name":"Ho"}, 
"HRI ": {"name":"Harari"}, 
"HRV ": {"name":"Croatian"}, 
"HUN ": {"name":"Hungarian"}, 
"HYE ": {"name":"Armenian"}, 
"IBA ": {"name":"Iban"}, 
"IBB ": {"name":"Ibibio"}, 
"IBO ": {"name":"Igbo"}, 
"IDO ": {"name":"Ido"}, 
"IJO ": {"name":"Ijo"}, 
"ILE ": {"name":"Interlingue"}, 
"ILO ": {"name":"Ilokano"}, 
"INA ": {"name":"Interlingua"}, 
"IND ": {"name":"Indonesian"}, 
"ING ": {"name":"Ingush"}, 
"INU ": {"name":"Inuktitut"}, 
"INUK": {"name":"Nunavik"}, 
"IPK ": {"name":"Inupiat"}, 
"IRI ": {"name":"Irish"}, 
"IRT ": {"name":"Irish"}, 
"IRU ": {"name":"Irula"}, 
"ISL ": {"name":"Icelandic"}, 
"ISM ": {"name":"Inari"}, 
"ITA ": {"name":"Italian"}, 
"IWR ": {"name":"Hebrew"}, 
"JAM ": {"name":"Jamaican"}, 
"JAN ": {"name":"Japanese"}, 
"JAV ": {"name":"Javanese"}, 
"JBO ": {"name":"Lojban"}, 
"JCT ": {"name":"Krymchak"}, 
"JII ": {"name":"Yiddish"}, 
"JUD ": {"name":"Ladino"}, 
"JUL ": {"name":"Jula"}, 
"KAB ": {"name":"Kabardian"}, 
"KAC ": {"name":"Kachchi"}, 
"KAL ": {"name":"Kalenjin"}, 
"KAN ": {"name":"Kannada"}, 
"KAR ": {"name":"Karachay"}, 
"KAT ": {"name":"Georgian"}, 
"KAW ": {"name":"Kawi"}, 
"KAZ ": {"name":"Kazakh"}, 
"KDE ": {"name":"Makonde"}, 
"KEA ": {"name":"Kabuverdianu"}, 
"KEB ": {"name":"Kebena"}, 
"KEK ": {"name":"Kekchi"}, 
"KGE ": {"name":"Khutsuri"}, 
"KHA ": {"name":"Khakass"}, 
"KHK ": {"name":"Khanty"}, 
"KHM ": {"name":"Khmer"}, 
"KHS ": {"name":"Khanty"}, 
"KHT ": {"name":"Khamti"}, 
"KHV ": {"name":"Khanty"}, 
"KHW ": {"name":"Khowar"}, 
"KIK ": {"name":"Kikuyu"}, 
"KIR ": {"name":"Kirghiz"}, 
"KIS ": {"name":"Kisii"}, 
"KIU ": {"name":"Kirmanjki"}, 
"KJD ": {"name":"Southern"}, 
"KJP ": {"name":"Eastern"}, 
"KJZ ": {"name":"Bumthangkha"}, 
"KKN ": {"name":"Kokni"}, 
"KLM ": {"name":"Kalmyk"}, 
"KMB ": {"name":"Kamba"}, 
"KMN ": {"name":"Kumaoni"}, 
"KMO ": {"name":"Komo"}, 
"KMS ": {"name":"Komso"}, 
"KMZ ": {"name":"Khorasani"}, 
"KNR ": {"name":"Kanuri"}, 
"KOD ": {"name":"Kodagu"}, 
"KOH ": {"name":"Korean"}, 
"KOK ": {"name":"Konkani"}, 
"KOM ": {"name":"Komi"}, 
"KON ": {"name":"Kikongo"}, 
"KOP ": {"name":"Komi"}, 
"KOR ": {"name":"Korean"}, 
"KOS ": {"name":"Kosraean"}, 
"KOZ ": {"name":"Komi"}, 
"KPL ": {"name":"Kpelle"}, 
"KRI ": {"name":"Krio"}, 
"KRK ": {"name":"Karakalpak"}, 
"KRL ": {"name":"Karelian"}, 
"KRM ": {"name":"Karaim"}, 
"KRN ": {"name":"Karen"}, 
"KRT ": {"name":"Koorete"}, 
"KSH ": {"name":"Kashmiri"}, 
"KSI ": {"name":"Khasi"}, 
"KSM ": {"name":"Kildin"}, 
"KSW ": {"name":"S’gaw"}, 
"KUA ": {"name":"Kuanyama"}, 
"KUI ": {"name":"Kui"}, 
"KUL ": {"name":"Kulvi"}, 
"KUM ": {"name":"Kumyk"}, 
"KUR ": {"name":"Kurdish"}, 
"KUU ": {"name":"Kurukh"}, 
"KUY ": {"name":"Kuy"}, 
"KWK ": {"name":"Kwakʼwala"}, 
"KYK ": {"name":"Koryak"}, 
"KYU ": {"name":"Western"}, 
"LAD ": {"name":"Ladin"}, 
"LAH ": {"name":"Lahuli"}, 
"LAK ": {"name":"Lak"}, 
"LAM ": {"name":"Lambani"}, 
"LAO ": {"name":"Lao"}, 
"LAT ": {"name":"Latin"}, 
"LAZ ": {"name":"Laz"}, 
"LCR ": {"name":"L"}, 
"LDK ": {"name":"Ladakhi"}, 
"LEF ": {"name":"Lelemi"}, 
"LEZ ": {"name":"Lezgi"}, 
"LIJ ": {"name":"Ligurian"}, 
"LIM ": {"name":"Limburgish"}, 
"LIN ": {"name":"Lingala"}, 
"LIS ": {"name":"Lisu"}, 
"LJP ": {"name":"Lampung"}, 
"LKI ": {"name":"Laki"}, 
"LMA ": {"name":"Low"}, 
"LMB ": {"name":"Limbu"}, 
"LMO ": {"name":"Lombard"}, 
"LMW ": {"name":"Lomwe"}, 
"LOM ": {"name":"Loma"}, 
"LPO ": {"name":"Lipo"}, 
"LRC ": {"name":"Luri"}, 
"LSB ": {"name":"Lower"}, 
"LSM ": {"name":"Lule"}, 
"LTH ": {"name":"Lithuanian"}, 
"LTZ ": {"name":"Luxembourgish"}, 
"LUA ": {"name":"Luba"}, 
"LUB ": {"name":"Luba"}, 
"LUG ": {"name":"Ganda"}, 
"LUH ": {"name":"Luyia"}, 
"LUO ": {"name":"Luo"}, 
"LVI ": {"name":"Latvian"}, 
"MAD ": {"name":"Madura"}, 
"MAG ": {"name":"Magahi"}, 
"MAH ": {"name":"Marshallese"}, 
"MAJ ": {"name":"Majang"}, 
"MAK ": {"name":"Makhuwa"}, 
"MAL ": {"name":"Malayalam"}, 
"MAM ": {"name":"Mam"}, 
"MAN ": {"name":"Mansi"}, 
"MAP ": {"name":"Mapudungun"}, 
"MAR ": {"name":"Marathi"}, 
"MAW ": {"name":"Marwari"}, 
"MBN ": {"name":"Mbundu"}, 
"MBO ": {"name":"Mbo"}, 
"MCH ": {"name":"Manchu"}, 
"MCR ": {"name":"Moose"}, 
"MDE ": {"name":"Mende"}, 
"MDR ": {"name":"Mandar"}, 
"MEN ": {"name":"Me’en"}, 
"MER ": {"name":"Meru"}, 
"MFA ": {"name":"Pattani"}, 
"MFE ": {"name":"Morisyen"}, 
"MIN ": {"name":"Minangkabau"}, 
"MIZ ": {"name":"Mizo"}, 
"MKD ": {"name":"Macedonian"}, 
"MKR ": {"name":"Makasar"}, 
"MKW ": {"name":"Kituba"}, 
"MLE ": {"name":"Male"}, 
"MLG ": {"name":"Malagasy"}, 
"MLN ": {"name":"Malinke"}, 
"MLR ": {"name":"Malayalam"}, 
"MLY ": {"name":"Malay"}, 
"MND ": {"name":"Mandinka"}, 
"MNG ": {"name":"Mongolian"}, 
"MNI ": {"name":"Manipuri"}, 
"MNK ": {"name":"Maninka"}, 
"MNX ": {"name":"Manx"}, 
"MOH ": {"name":"Mohawk"}, 
"MOK ": {"name":"Moksha"}, 
"MOL ": {"name":"Moldavian"}, 
"MON ": {"name":"Mon"}, 
"MONT": {"name":"Thailand"}, 
"MOR ": {"name":"Moroccan"}, 
"MOS ": {"name":"Mossi"}, 
"MRI ": {"name":"Maori"}, 
"MTH ": {"name":"Maithili"}, 
"MTS ": {"name":"Maltese"}, 
"MUN ": {"name":"Mundari"}, 
"MUS ": {"name":"Muscogee"}, 
"MWL ": {"name":"Mirandese"}, 
"MWW ": {"name":"Hmong"}, 
"MYN ": {"name":"Mayan"}, 
"MZN ": {"name":"Mazanderani"}, 
"NAG ": {"name":"Naga"}, 
"NAH ": {"name":"Nahuatl"}, 
"NAN ": {"name":"Nanai"}, 
"NAP ": {"name":"Neapolitan"}, 
"NAS ": {"name":"Naskapi"}, 
"NAU ": {"name":"Nauruan"}, 
"NAV ": {"name":"Navajo"}, 
"NCR ": {"name":"N"}, 
"NDB ": {"name":"Ndebele"}, 
"NDC ": {"name":"Ndau"}, 
"NDG ": {"name":"Ndonga"}, 
"NDS ": {"name":"Low"}, 
"NEP ": {"name":"Nepali"}, 
"NEW ": {"name":"Newari"}, 
"NGA ": {"name":"Ngbaka"}, 
"NGR ": {"name":"Nagari"}, 
"NHC ": {"name":"Norway"}, 
"NIS ": {"name":"Nisi"}, 
"NIU ": {"name":"Niuean"}, 
"NKL ": {"name":"Nyankole"}, 
"NKO ": {"name":"N’Ko"}, 
"NLD ": {"name":"Dutch"}, 
"NOE ": {"name":"Nimadi"}, 
"NOG ": {"name":"Nogai"}, 
"NOR ": {"name":"Norwegian"}, 
"NOV ": {"name":"Novial"}, 
"NSM ": {"name":"Northern"}, 
"NSO ": {"name":"Northern"}, 
"NTA ": {"name":"Northern"}, 
"NTO ": {"name":"Esperanto"}, 
"NYM ": {"name":"Nyamwezi"}, 
"NYN ": {"name":"Norwegian"}, 
"NZA ": {"name":"Mbembe"}, 
"OCI ": {"name":"Occitan"}, 
"OCR ": {"name":"Oji"}, 
"OJB ": {"name":"Ojibway"}, 
"ORI ": {"name":"Odia"}, 
"ORO ": {"name":"Oromo"}, 
"OSS ": {"name":"Ossetian"}, 
"PAA ": {"name":"Palestinian"}, 
"PAG ": {"name":"Pangasinan"}, 
"PAL ": {"name":"Pali"}, 
"PAM ": {"name":"Pampangan"}, 
"PAN ": {"name":"Punjabi"}, 
"PAP ": {"name":"Palpa"}, 
"PAS ": {"name":"Pashto"}, 
"PAU ": {"name":"Palauan"}, 
"PCC ": {"name":"Bouyei"}, 
"PCD ": {"name":"Picard"}, 
"PDC ": {"name":"Pennsylvania"}, 
"PGR ": {"name":"Polytonic"}, 
"PHK ": {"name":"Phake"}, 
"PIH ": {"name":"Norfolk"}, 
"PIL ": {"name":"Filipino"}, 
"PLG ": {"name":"Palaung"}, 
"PLK ": {"name":"Polish"}, 
"PMS ": {"name":"Piemontese"}, 
"PNB ": {"name":"Western"}, 
"POH ": {"name":"Pocomchi"}, 
"PON ": {"name":"Pohnpeian"}, 
"PRO ": {"name":"Provençal"}, 
"PTG ": {"name":"Portuguese"}, 
"PWO ": {"name":"Western"}, 
"QIN ": {"name":"Chin"}, 
"QUC ": {"name":"K’iche’"}, 
"QUH ": {"name":"Quechua"}, 
"QUZ ": {"name":"Quechua"}, 
"QVI ": {"name":"Quechua"}, 
"QWH ": {"name":"Quechua"}, 
"RAJ ": {"name":"Rajasthani"}, 
"RAR ": {"name":"Rarotongan"}, 
"RBU ": {"name":"Russian"}, 
"RCR ": {"name":"R"}, 
"REJ ": {"name":"Rejang"}, 
"RIA ": {"name":"Riang"}, 
"RHG ": {"name":"Rohingya"}, 
"RIF ": {"name":"Tarifit"}, 
"RIT ": {"name":"Ritarungo"}, 
"RKW ": {"name":"Arakwal"}, 
"RMS ": {"name":"Romansh"}, 
"RMY ": {"name":"Vlax"}, 
"ROM ": {"name":"Romanian"}, 
"ROY ": {"name":"Romany"}, 
"RSY ": {"name":"Rusyn"}, 
"RTM ": {"name":"Rotuman"}, 
"RUA ": {"name":"Kinyarwanda"}, 
"RUN ": {"name":"Rundi"}, 
"RUP ": {"name":"Aromanian"}, 
"RUS ": {"name":"Russian"}, 
"SAD ": {"name":"Sadri"}, 
"SAN ": {"name":"Sanskrit"}, 
"SAS ": {"name":"Sasak"}, 
"SAT ": {"name":"Santali"}, 
"SAY ": {"name":"Sayisi"}, 
"SCN ": {"name":"Sicilian"}, 
"SCO ": {"name":"Scots"}, 
"SCS ": {"name":"North"}, 
"SEK ": {"name":"Sekota"}, 
"SEL ": {"name":"Selkup"}, 
"SFM ": {"name":"Small"}, 
"SGA ": {"name":"Old"}, 
"SGO ": {"name":"Sango"}, 
"SGS ": {"name":"Samogitian"}, 
"SHI ": {"name":"Tachelhit"}, 
"SHN ": {"name":"Shan"}, 
"SIB ": {"name":"Sibe"}, 
"SID ": {"name":"Sidamo"}, 
"SIG ": {"name":"Silte"}, 
"SKS ": {"name":"Skolt"}, 
"SKY ": {"name":"Slovak"}, 
"SLA ": {"name":"Slavey"}, 
"SLV ": {"name":"Slovenian"}, 
"SML ": {"name":"Somali"}, 
"SMO ": {"name":"Samoan"}, 
"SNA ": {"name":"Sena"}, 
"SND ": {"name":"Sindhi"}, 
"SNH ": {"name":"Sinhala"}, 
"SNK ": {"name":"Soninke"}, 
"SOG ": {"name":"Sodo"}, 
"SOP ": {"name":"Songe"}, 
"SOT ": {"name":"Southern"}, 
"SQI ": {"name":"Albanian"}, 
"SRB ": {"name":"Serbian"}, 
"SRD ": {"name":"Sardinian"}, 
"SRK ": {"name":"Saraiki"}, 
"SRR ": {"name":"Serer"}, 
"SSL ": {"name":"South"}, 
"SSM ": {"name":"Southern"}, 
"STQ ": {"name":"Saterland"}, 
"SUK ": {"name":"Sukuma"}, 
"SUN ": {"name":"Sundanese"}, 
"SUR ": {"name":"Suri"}, 
"SVA ": {"name":"Svan"}, 
"SVE ": {"name":"Swedish"}, 
"SWA ": {"name":"Swadaya"}, 
"SWK ": {"name":"Swahili"}, 
"SWZ ": {"name":"Swati"}, 
"SXT ": {"name":"Sutu"}, 
"SXU ": {"name":"Upper"}, 
"SYL ": {"name":"Sylheti"}, 
"SYR ": {"name":"Syriac"}, 
"SYRE": {"name":"Syriac"}, 
"SYRJ": {"name":"Syriac"}, 
"SYRN": {"name":"Syriac"}, 
"SZL ": {"name":"Silesian"}, 
"TAB ": {"name":"Tabasaran"}, 
"TAJ ": {"name":"Tajiki"}, 
"TAM ": {"name":"Tamil"}, 
"TAT ": {"name":"Tatar"}, 
"TCR ": {"name":"TH"}, 
"TDD ": {"name":"Dehong"}, 
"TEL ": {"name":"Telugu"}, 
"TET ": {"name":"Tetum"}, 
"TGL ": {"name":"Tagalog"}, 
"TGN ": {"name":"Tongan"}, 
"TGR ": {"name":"Tigre"}, 
"TGY ": {"name":"Tigrinya"}, 
"THA ": {"name":"Thai"}, 
"THT ": {"name":"Tahitian"}, 
"TIB ": {"name":"Tibetan"}, 
"TIV ": {"name":"Tiv"}, 
"TJL ": {"name":"Tai"}, 
"TKM ": {"name":"Turkmen"}, 
"TLI ": {"name":"Tlingit"}, 
"TMH ": {"name":"Tamashek"}, 
"TMN ": {"name":"Temne"}, 
"TNA ": {"name":"Tswana"}, 
"TNE ": {"name":"Tundra"}, 
"TNG ": {"name":"Tonga"}, 
"TOD ": {"name":"Todo"}, 
"TPI ": {"name":"Tok"}, 
"TRK ": {"name":"Turkish"}, 
"TSG ": {"name":"Tsonga"}, 
"TSJ ": {"name":"Tshangla"}, 
"TUA ": {"name":"Turoyo"}, 
"TUL ": {"name":"Tulu"}, 
"TUM ": {"name":"Tumbuka"}, 
"TUV ": {"name":"Tuvin"}, 
"TVL ": {"name":"Tuvalu"}, 
"TWI ": {"name":"Twi"}, 
"TYZ ": {"name":"Tày"}, 
"TZM ": {"name":"Tamazight"}, 
"TZO ": {"name":"Tzotzil"}, 
"UDM ": {"name":"Udmurt"}, 
"UKR ": {"name":"Ukrainian"}, 
"UMB ": {"name":"Umbundu"}, 
"URD ": {"name":"Urdu"}, 
"USB ": {"name":"Upper"}, 
"UYG ": {"name":"Uyghur"}, 
"UZB ": {"name":"Uzbek"}, 
"VEC ": {"name":"Venetian"}, 
"VEN ": {"name":"Venda"}, 
"VIT ": {"name":"Vietnamese"}, 
"VOL ": {"name":"Volapük"}, 
"VRO ": {"name":"Võro"}, 
"WA  ": {"name":"Wa"}, 
"WAG ": {"name":"Wagdi"}, 
"WAR ": {"name":"Waray"}, 
"WCI ": {"name":"Waci"}, 
"WCR ": {"name":"West"}, 
"WEL ": {"name":"Welsh"}, 
"WLF ": {"name":"Wolof"}, 
"WLN ": {"name":"Walloon"}, 
"WTM ": {"name":"Mewati"}, 
"XBD ": {"name":"Lü"}, 
"XHS ": {"name":"Xhosa"}, 
"XJB ": {"name":"Minjangbal"}, 
"XKF ": {"name":"Khengkha"}, 
"XOG ": {"name":"Soga"}, 
"XPE ": {"name":"Kpelle"}, 
"XUB ": {"name":"Bette"}, 
"XUJ ": {"name":"Jennu"}, 
"YAK ": {"name":"Sakha"}, 
"YAO ": {"name":"Yao"}, 
"YAP ": {"name":"Yapese"}, 
"YBA ": {"name":"Yoruba"}, 
"YCR ": {"name":"Y"}, 
"YGP ": {"name":"Gepo"}, 
"YIC ": {"name":"Yi"}, 
"YIM ": {"name":"Yi"}, 
"YNA ": {"name":"Aluo"}, 
"YWQ ": {"name":"Wuding"}, 
"ZEA ": {"name":"Zealandic"}, 
"ZGH ": {"name":"Standard"}, 
"ZHA ": {"name":"Zhuang"}, 
"ZHH ": {"name":"Chinese"}, 
"ZHP ": {"name":"Chinese"}, 
"ZHS ": {"name":"Chinese"}, 
"ZHT ": {"name":"Chinese"}, 
"ZHTM": {"name":"Chinese"}, 
"ZND ": {"name":"Zande"}, 
"ZUL ": {"name":"Zulu"}, 
"ZZA ": {"name":"Zazaki"}
}
